Changelog
=========

Unreleased
==========

- The ``Component`` protocol now indicates it returns a ``VDOM``

- Tolerate usage of generics such as `Optional[str]`

- Switch to ``wired_injector``

0.1.0
=====

First release.
